import type { Client } from '../Client';
import * as Types from '../types';
import { PaginationParams } from '../constants';
export declare class Charges {
    protected client: Client;
    constructor(client: Client);
    /**
     * Retrieves a charge.
     * @param chargeId
     * @returns Promise<ICharge>
     */
    retrieve(chargeId: string): Promise<Types.Charges.ICharge>;
    /**
     * Creates a charge.
     * @param chargeData
     * @returns Promise<ICharge>
     */
    create(chargeData: Types.Charges.IRequest): Promise<Types.Charges.ICharge>;
    /**
     * Updates a charge.
     * @param chargeId
     * @param chargeData
     * @returns Promise<ICharge>
     */
    update(chargeId: string, chargeData: Types.Charges.IRequest): Promise<Types.Charges.ICharge>;
    /**
     * Reverses a charge.
     * @param chargeId
     * @returns Promise<ICharge>
     */
    reverse(chargeId: string): Promise<Types.Charges.ICharge>;
    /**
     * Captures an un-captured charge.
     * @param chargeId
     * @returns Promise<ICharge>
     */
    capture(chargeId: string): Promise<Types.Charges.ICharge>;
    /**
     * Expires a charge.
     * @param chargeId
     * @returns Promise<ICharge>
     */
    expire(chargeId: string): Promise<Types.Charges.ICharge>;
    /**
     * Dispute a charge.
     * @param chargeId
     * @returns Promise<ICharge>
     */
    dispute(chargeId: string): Promise<Types.Charges.ICharge>;
    /**
     * Lists all charges.
     * @returns Promise<IChargeList>
     */
    list(params?: PaginationParams): Promise<Types.Charges.IChargeList>;
}
