"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Charges = void 0;
var constants_1 = require("../constants");
var Charges = /** @class */ (function () {
    function Charges(client) {
        this.client = client;
    }
    /**
     * Retrieves a charge.
     * @param chargeId
     * @returns Promise<ICharge>
     */
    Charges.prototype.retrieve = function (chargeId) {
        return this.client.request({
            method: 'get',
            path: "".concat(constants_1.CHARGES_RESOURCE, "/").concat(chargeId),
        });
    };
    /**
     * Creates a charge.
     * @param chargeData
     * @returns Promise<ICharge>
     */
    Charges.prototype.create = function (chargeData) {
        return this.client.request({
            method: 'post',
            path: constants_1.CHARGES_RESOURCE,
            data: chargeData,
        });
    };
    /**
     * Updates a charge.
     * @param chargeId
     * @param chargeData
     * @returns Promise<ICharge>
     */
    Charges.prototype.update = function (chargeId, chargeData) {
        return this.client.request({
            method: 'patch',
            path: "".concat(constants_1.CHARGES_RESOURCE, "/").concat(chargeId),
            data: chargeData,
        });
    };
    /**
     * Reverses a charge.
     * @param chargeId
     * @returns Promise<ICharge>
     */
    Charges.prototype.reverse = function (chargeId) {
        return this.client.request({
            method: 'post',
            path: "".concat(constants_1.CHARGES_RESOURCE, "/").concat(chargeId, "/reverse"),
        });
    };
    /**
     * Captures an un-captured charge.
     * @param chargeId
     * @returns Promise<ICharge>
     */
    Charges.prototype.capture = function (chargeId) {
        return this.client.request({
            method: 'post',
            path: "".concat(constants_1.CHARGES_RESOURCE, "/").concat(chargeId, "/capture"),
        });
    };
    /**
     * Expires a charge.
     * @param chargeId
     * @returns Promise<ICharge>
     */
    Charges.prototype.expire = function (chargeId) {
        return this.client.request({
            method: 'post',
            path: "".concat(constants_1.CHARGES_RESOURCE, "/").concat(chargeId, "/expire"),
        });
    };
    /**
     * Dispute a charge.
     * @param chargeId
     * @returns Promise<ICharge>
     */
    Charges.prototype.dispute = function (chargeId) {
        return this.client.request({
            method: 'post',
            path: "".concat(constants_1.CHARGES_RESOURCE, "/").concat(chargeId, "/dispute"),
        });
    };
    /**
     * Lists all charges.
     * @returns Promise<IChargeList>
     */
    Charges.prototype.list = function (params) {
        return this.client.request({
            method: 'get',
            path: constants_1.CHARGES_RESOURCE,
            params: params,
        });
    };
    return Charges;
}());
exports.Charges = Charges;
