import type { Client } from '../Client';
import * as Types from '../types';
import { PaginationParams } from '../constants';
export declare class Customers {
    protected client: Client;
    constructor(client: Client);
    /**
     * Retrieves a customer.
     * @param customerId
     * @returns Promise<ICustomer>
     */
    retrieve(customerId: string): Promise<Types.Customers.ICustomer>;
    /**
     * Creates a customer.
     * @param customerData
     * @returns Promise<ICustomer>
     */
    create(customerData: Types.Customers.IRequest): Promise<Types.Customers.ICustomer>;
    /**
     * Updates a customer.
     * @param customerId
     * @param customer the attributes of the customer to update
     * @returns Promise<ICustomer>
     */
    update(customerId: string, customer: Types.Customers.IRequest): Promise<Types.Customers.ICustomer>;
    /**
     * Deletes a customer.
     * @param customerId
     * @returns Promise<ICustomer>
     */
    destroy(customerId: string): Promise<Types.Customers.ICustomer>;
    /**
     * List all customers.
     * @returns Promise<ICustomerList>
     *
     */
    list(params?: PaginationParams): Promise<Types.Customers.ICustomerList>;
    /**
     * Deletes a card belonging to the customer.
     * @param customerId
     * @param cardId
     * @return Promise<ICard>
     */
    destroyCard(customerId: string, cardId: string): Promise<Types.Cards.ICard>;
    /**
     * Updates the default card for a customer.
     * @param customerId string
     * @param cardToken string
     * @returns Promise<ICustomer>
     */
    updateDefaultCard(customerId: string, cardId: string): Promise<Types.Customers.ICustomer>;
    /**
     * Adds a new card to a customer and sets the newly added card as the default.
     * @param customerId string
     * @param cardToken string
     * @returns Promise<ICustomer>
     */
    addCardAsDefault(customerId: string, cardToken: string): Promise<Types.Customers.ICustomer>;
    /**
     * List all schedules for a customer.
     * @param customerId
     * @returns Promise<ISchedulesList>
     */
    listSchedules(customerId: string, params?: PaginationParams): Promise<Types.Schedules.ISchedulesList>;
    /**
     * Deletes all schedules for a customer.
     * @param customerId
     * @return Promise<IDestroyResponse>
     */
    destroySchedules(customerId: string): Promise<Partial<Types.IDestroyResponse>>;
}
