"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __generator = (this && this.__generator) || function (thisArg, body) {
    var _ = { label: 0, sent: function() { if (t[0] & 1) throw t[1]; return t[1]; }, trys: [], ops: [] }, f, y, t, g;
    return g = { next: verb(0), "throw": verb(1), "return": verb(2) }, typeof Symbol === "function" && (g[Symbol.iterator] = function() { return this; }), g;
    function verb(n) { return function (v) { return step([n, v]); }; }
    function step(op) {
        if (f) throw new TypeError("Generator is already executing.");
        while (_) try {
            if (f = 1, y && (t = op[0] & 2 ? y["return"] : op[0] ? y["throw"] || ((t = y["return"]) && t.call(y), 0) : y.next) && !(t = t.call(y, op[1])).done) return t;
            if (y = 0, t) op = [op[0] & 2, t.value];
            switch (op[0]) {
                case 0: case 1: t = op; break;
                case 4: _.label++; return { value: op[1], done: false };
                case 5: _.label++; y = op[1]; op = [0]; continue;
                case 7: op = _.ops.pop(); _.trys.pop(); continue;
                default:
                    if (!(t = _.trys, t = t.length > 0 && t[t.length - 1]) && (op[0] === 6 || op[0] === 2)) { _ = 0; continue; }
                    if (op[0] === 3 && (!t || (op[1] > t[0] && op[1] < t[3]))) { _.label = op[1]; break; }
                    if (op[0] === 6 && _.label < t[1]) { _.label = t[1]; t = op; break; }
                    if (t && _.label < t[2]) { _.label = t[2]; _.ops.push(op); break; }
                    if (t[2]) _.ops.pop();
                    _.trys.pop(); continue;
            }
            op = body.call(thisArg, _);
        } catch (e) { op = [6, e]; y = 0; } finally { f = t = 0; }
        if (op[0] & 5) throw op[1]; return { value: op[0] ? op[1] : void 0, done: true };
    }
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.Customers = void 0;
var constants_1 = require("../constants");
var Customers = /** @class */ (function () {
    function Customers(client) {
        this.client = client;
    }
    /**
     * Retrieves a customer.
     * @param customerId
     * @returns Promise<ICustomer>
     */
    Customers.prototype.retrieve = function (customerId) {
        return this.client.request({
            method: 'get',
            path: "".concat(constants_1.CUSTOMERS_RESOURCE, "/").concat(customerId),
        });
    };
    /**
     * Creates a customer.
     * @param customerData
     * @returns Promise<ICustomer>
     */
    Customers.prototype.create = function (customerData) {
        return this.client.request({
            method: 'post',
            path: constants_1.CUSTOMERS_RESOURCE,
            data: customerData,
        });
    };
    /**
     * Updates a customer.
     * @param customerId
     * @param customer the attributes of the customer to update
     * @returns Promise<ICustomer>
     */
    Customers.prototype.update = function (customerId, customer) {
        return this.client.request({
            method: 'patch',
            path: "".concat(constants_1.CUSTOMERS_RESOURCE, "/").concat(customerId),
            data: customer,
        });
    };
    /**
     * Deletes a customer.
     * @param customerId
     * @returns Promise<ICustomer>
     */
    Customers.prototype.destroy = function (customerId) {
        return this.client.request({
            method: 'delete',
            path: "".concat(constants_1.CUSTOMERS_RESOURCE, "/").concat(customerId),
        });
    };
    /**
     * List all customers.
     * @returns Promise<ICustomerList>
     *
     */
    Customers.prototype.list = function (params) {
        return this.client.request({
            method: 'get',
            path: constants_1.CUSTOMERS_RESOURCE,
            params: params,
        });
    };
    /**
     * Deletes a card belonging to the customer.
     * @param customerId
     * @param cardId
     * @return Promise<ICard>
     */
    Customers.prototype.destroyCard = function (customerId, cardId) {
        return __awaiter(this, void 0, void 0, function () {
            return __generator(this, function (_a) {
                return [2 /*return*/, this.client.request({
                        method: 'delete',
                        path: "".concat(constants_1.CUSTOMERS_RESOURCE, "/").concat(customerId, "/").concat(constants_1.CARDS_RESOURCE, "/").concat(cardId),
                    })];
            });
        });
    };
    /**
     * Updates the default card for a customer.
     * @param customerId string
     * @param cardToken string
     * @returns Promise<ICustomer>
     */
    Customers.prototype.updateDefaultCard = function (customerId, cardId) {
        return __awaiter(this, void 0, void 0, function () {
            return __generator(this, function (_a) {
                return [2 /*return*/, this.update(customerId, { default_card: cardId })];
            });
        });
    };
    /**
     * Adds a new card to a customer and sets the newly added card as the default.
     * @param customerId string
     * @param cardToken string
     * @returns Promise<ICustomer>
     */
    Customers.prototype.addCardAsDefault = function (customerId, cardToken) {
        return __awaiter(this, void 0, void 0, function () {
            var updatedCustomer, allCards, newCard;
            return __generator(this, function (_a) {
                switch (_a.label) {
                    case 0: return [4 /*yield*/, this.update(customerId, {
                            card: cardToken,
                        })];
                    case 1:
                        updatedCustomer = _a.sent();
                        allCards = updatedCustomer.cards.data;
                        newCard = allCards[allCards.length - 1];
                        return [2 /*return*/, this.updateDefaultCard(customerId, newCard.id)];
                }
            });
        });
    };
    /**
     * List all schedules for a customer.
     * @param customerId
     * @returns Promise<ISchedulesList>
     */
    Customers.prototype.listSchedules = function (customerId, params) {
        return this.client.request({
            method: 'get',
            path: "".concat(constants_1.CUSTOMERS_RESOURCE, "/").concat(customerId, "/").concat(constants_1.SCHEDULES_RESOURCE),
            params: params,
        });
    };
    /**
     * Deletes all schedules for a customer.
     * @param customerId
     * @return Promise<IDestroyResponse>
     */
    Customers.prototype.destroySchedules = function (customerId) {
        var _a, _b;
        return __awaiter(this, void 0, void 0, function () {
            var schedules, activeScheduleIds, deleteSchedulesPromises;
            var _this = this;
            return __generator(this, function (_c) {
                switch (_c.label) {
                    case 0: return [4 /*yield*/, this.listSchedules(customerId, {
                            order: 'reverse_chronological',
                            limit: 50, // use a high limit in the hope of catching all schedules that might still be active
                        })];
                    case 1:
                        schedules = _c.sent();
                        activeScheduleIds = (_b = (_a = schedules === null || schedules === void 0 ? void 0 : schedules.data) === null || _a === void 0 ? void 0 : _a.filter(function (schedule) { return schedule === null || schedule === void 0 ? void 0 : schedule.active; })) === null || _b === void 0 ? void 0 : _b.map(function (schedule) { return schedule === null || schedule === void 0 ? void 0 : schedule.id; });
                        deleteSchedulesPromises = activeScheduleIds.map(function (scheduleId) {
                            return _this.client.schedules.destroy(scheduleId);
                        });
                        return [4 /*yield*/, Promise.all(deleteSchedulesPromises)];
                    case 2:
                        _c.sent();
                        return [2 /*return*/, {
                                deleted: true,
                            }];
                }
            });
        });
    };
    return Customers;
}());
exports.Customers = Customers;
